summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/notation/NotationElement.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-06 20:59:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-06 20:59:29 +0000
commit11f31c37e5fa4889d9989f10272f44845449cb7b (patch)
tree4383da04a76c497950d957fc6120b0fd0d9082c2 /src/gui/editors/notation/NotationElement.h
parent832eb69d571e8e518db45d0c0e6fbc0f00690209 (diff)
downloadrosegarden-11f31c37e5fa4889d9989f10272f44845449cb7b.tar.gz
rosegarden-11f31c37e5fa4889d9989f10272f44845449cb7b.zip
Initial TQt conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1172292 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/editors/notation/NotationElement.h')
-rw-r--r--src/gui/editors/notation/NotationElement.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/gui/editors/notation/NotationElement.h b/src/gui/editors/notation/NotationElement.h
index c756641..2bb036f 100644
--- a/src/gui/editors/notation/NotationElement.h
+++ b/src/gui/editors/notation/NotationElement.h
@@ -32,7 +32,7 @@
#include "base/Event.h"
-class QCanvasItem;
+class TQCanvasItem;
class ItemList;
@@ -45,7 +45,7 @@ class Event;
/**
* The Notation H and V layout is performed on a
* NotationElementList. Once this is done, each NotationElement is
* affected a QCanvasItem which is set at these coords.
*
* @see NotationView#showElements()
*/
@@ -105,7 +105,7 @@ public:
*
* NOTE: The object takes ownership of its canvas item.
*/
- void setCanvasItem(QCanvasItem *e, double canvasX, double canvasY);
+ void setCanvasItem(TQCanvasItem *e, double canvasX, double canvasY);
/**
* Add an extra canvas item associated with this element, for
@@ -115,7 +115,7 @@ public:
* The element will take ownership of these canvas items and
* delete them when it deletes the main canvas item.
*/
- void addCanvasItem(QCanvasItem *e, double canvasX, double canvasY);
+ void addCanvasItem(TQCanvasItem *e, double canvasX, double canvasY);
/**
* Remove the main canvas item and any additional ones.
@@ -151,7 +151,7 @@ public:
void setIsColliding(bool value) { m_isColliding = value; }
/// Returns the associated canvas item
- QCanvasItem* getCanvasItem() { return m_canvasItem; }
+ TQCanvasItem* getCanvasItem() { return m_canvasItem; }
protected:
//--------------- Data members ---------------------------------
@@ -161,9 +161,9 @@ protected:
bool m_recentlyRegenerated;
bool m_isColliding;
- QCanvasItem *m_canvasItem;
+ TQCanvasItem *m_canvasItem;
- typedef std::vector<QCanvasItem *> ItemList;
+ typedef std::vector<TQCanvasItem *> ItemList;
ItemList *m_extraItems;
};
@@ -45,7 +45,7 @@ class Event;
* The Notation H and V layout is performed on a
* NotationElementList. Once this is done, each NotationElement is
- * affected a QCanvasItem which is set at these coords.
+ * affected a TQCanvasItem which is set at these coords.
*
* @see NotationView#showElements()